@@ -69,7 +69,8 @@ class PackageController(BaseController):
         try:
             c.fields = []
             for (param, value) in request.params.items():
-                if not param in ['q', 'open_only', 'downloadable_only', 'page'] and len(value):
+                if not param in ['q', 'open_only', 'downloadable_only', 'page'] \
+                        and len(value) and not param.startswith('_'):
                     c.fields.append((param, value))
 
             query.run(query=q,
@@ -114,7 +115,7 @@ class PackageController(BaseController):
         #check if package exists
         c.pkg = model.Package.get(id)
         if c.pkg is None:
-            abort(404, gettext('Package not found'))
+            abort(404, _('Package not found'))
         
         cache_key = self._pkg_cache_key(c.pkg)        
         etag_cache(cache_key)
@@ -136,7 +137,7 @@ class PackageController(BaseController):
         #is the user allowed to see this package?
         auth_for_read = self.authorizer.am_authorized(c, model.Action.READ, c.pkg)
         if not auth_for_read:
-            abort(401, gettext('Unauthorized to read package %s') % id)
+            abort(401, _('Unauthorized to read package %s') % id)
         
         for item in self.extensions:
             item.read(c.pkg)
@@ -150,7 +151,7 @@ class PackageController(BaseController):
         #check if package exists
         c.pkg = model.Package.get(id)
         if c.pkg is None:
-            abort(404, gettext('Package not found'))
+            abort(404, _('Package not found'))
 
         # used by disqus plugin
         c.current_package_id = c.pkg.id
@@ -158,7 +159,7 @@ class PackageController(BaseController):
         #is the user allowed to see this package?
         auth_for_read = self.authorizer.am_authorized(c, model.Action.READ, c.pkg)
         if not auth_for_read:
-            abort(401, gettext('Unauthorized to read package %s') % id)
+            abort(401, _('Unauthorized to read package %s') % id)
 
         for item in self.extensions:
             item.read(c.pkg)
@@ -185,7 +186,7 @@ class PackageController(BaseController):
 
         c.pkg = model.Package.get(id)
         if not c.pkg:
-            abort(404, gettext('Package not found'))
+            abort(404, _('Package not found'))
         format = request.params.get('format', '')
         if format == 'atom':
             # Generate and return Atom 1.0 document.
@@ -236,7 +237,7 @@ class PackageController(BaseController):
         # Check access control for user to create a package.
         auth_for_create = self.authorizer.am_authorized(c, model.Action.PACKAGE_CREATE, model.System())
         if not auth_for_create:
-            abort(401, gettext('Unauthorized to create a package'))
+            abort(401, _('Unauthorized to create a package'))
         # Get the name of the package form.
         fs = self._get_package_fieldset(is_admin=is_admin)
         if 'save' in request.params or 'preview' in request.params:
@@ -308,7 +309,7 @@ class PackageController(BaseController):
         model.Session().autoflush = False
         am_authz = self.authorizer.am_authorized(c, model.Action.EDIT, pkg)
         if not am_authz:
-            abort(401, gettext('User %r not authorized to edit %s') % (c.user, id))
+            abort(401, _('User %r not authorized to edit %s') % (c.user, id))
 
         auth_for_change_state = self.authorizer.am_authorized(c, model.Action.CHANGE_STATE, pkg)
         fs = self._get_package_fieldset(is_admin=auth_for_change_state)
