@@ -1,6 +1,7 @@
 import os
 import sys
 import logging
+from pprint import pprint
 
 import paste.script
 from paste.script.util.logging_config import fileConfig
@@ -39,7 +40,7 @@ class CkanCommand(paste.script.command.Command):
 class ManageDb(CkanCommand):
     '''Perform various tasks on the database.
     
-    db create # create
+    db create # alias of db upgrade
     db init # create and put in default data
     db clean
     db upgrade [{version no.}] # Data migrate
@@ -49,6 +50,7 @@ class ManageDb(CkanCommand):
     db simple-dump-json {file-path}
     db send-rdf {talis-store} {username} {password}
     db load {file-path} # load a dump from a file
+    db create-from-model # create database from the model (indexes not made)
     db migrate06
     db migrate09a
     db migrate09b
@@ -67,11 +69,7 @@ class ManageDb(CkanCommand):
         from ckan import model
 
         cmd = self.args[0]
-        if cmd == 'create':
-            model.repo.create_db()
-            if self.verbose:
-                print 'Creating DB: SUCCESS'
-        elif cmd == 'init':
+        if cmd == 'init':
             model.repo.init_db()
             if self.verbose:
                 print 'Initialising DB: SUCCESS'
@@ -92,6 +90,10 @@ class ManageDb(CkanCommand):
             self.simple_dump_json(cmd)
         elif cmd == 'dump-rdf':
             self.dump_rdf(cmd)
+        elif cmd == 'create-from-model':
+            model.repo.create_db()
+            if self.verbose:
+                print 'Creating DB: SUCCESS'
         elif cmd == 'send-rdf':
             self.send_rdf(cmd)
         elif cmd == 'migrate06':
@@ -215,7 +217,7 @@ class SearchIndexCommand(CkanCommand):
 
 
 class Sysadmin(CkanCommand):
-    '''Gives sysadmin rights to a named 
+    '''Gives sysadmin rights to a named user
 
     Usage:
       sysadmin list                 - lists sysadmins
@@ -285,6 +287,146 @@ class Sysadmin(CkanCommand):
             return
         model.remove_user_from_role(user, model.Role.ADMIN, model.System())
         model.repo.commit_and_remove()
+
+
+class UserCmd(CkanCommand):
+    '''Manage users
+
+    Usage:
+      user                            - lists users
+      user <user-name>                - shows user properties
+      user add <user-name> [<apikey>] - add a user (prompts for password)
+      user setpass <user-name>        - set user password (prompts)
+      user remove <user-name>         - removes user from users
+      user search <query>             - searches for a user name
+    '''
+    summary = __doc__.split('\n')[0]
+    usage = __doc__
+    max_args = 3
+    min_args = 0
+
+    def command(self):
+        self._load_config()
+        from ckan import model
+
+        if not self.args:
+            self.list()
+        else:
+            cmd = self.args[0]
+            if cmd == 'add':
+                self.add()
+            elif cmd == 'remove':
+                self.remove()
+            elif cmd == 'search':
+                self.search()
+            elif cmd == 'setpass':
+                self.setpass()
+            else:
+                self.show()
+
+    def get_user_str(self, user):
+        user_str = 'name=%s' % user.name
+        if user.name != user.display_name:
+            user_str += ' display=%s' % user.display_name
+        return user_str
+        
+    def list(self):
+        from ckan import model
+        print 'Users:'
+        users = model.Session.query(model.User).all()
+        for user in users:
+            print self.get_user_str(user)
+
+    def show(self):
+        from ckan import model
+
+        username = self.args[0]
+        user = model.User.get(unicode(username))
+        print 'User: \n', user
+
+    def setpass(self):
+        from ckan import model
+        import getpass
+        
+        if len(self.args) < 2:
+            print 'Need name of the user.'
+            return
+        username = self.args[1]
+        user = model.User.get(username)
+        print('Editing user: %r' % user.name)
+
+        password1 = None
+        while not password1:
+            password1 = getpass.getpass('Password: ')
+        password2 = getpass.getpass('Confirm password: ')
+        if password1 != password2:
+            print 'Passwords do not match'
+            sys.exit(1)
+        user.password = password1
+        model.repo.commit_and_remove()
+        print 'Done'
+
+    def search(self):
+        from ckan import model
+
+        if len(self.args) < 2:
+            print 'Need user name query string.'
+            return
+        query_str = self.args[1]
+
+        query = model.User.search(query_str)
+        print '%i users matching %r:' % (query.count(), query_str)
+        for user in query.all():
+            print self.get_user_str(user)
+
+    def add(self):
+        from ckan import model
+        import getpass
+        
+        if len(self.args) < 2:
+            print 'Need name of the user.'
+            return
+        username = self.args[1]
+        apikey = self.args[2] if len(self.args) > 2 else None
+
+        user = model.User.by_name(unicode(username))
+        if user:
+            print 'User "%s" already found' % username
+            sys.exit(1)
+        
+        print('Creating user: %r' % username)
+        password1 = None
+        while not password1:
+            password1 = getpass.getpass('Password: ')
+        password2 = getpass.getpass('Confirm password: ')
+        if password1 != password2:
+            print 'Passwords do not match'
+            sys.exit(1)
+        user_params = {'name': unicode(username),
+                   'password': password1}
+        if apikey:
+            user_params['apikey'] = unicode(apikey)
+        user = model.User(**user_params)
+        model.Session.add(user)
+        model.repo.commit_and_remove()
+        user = model.User.by_name(unicode(username))
+        print user
+
+    def remove(self):
+        from ckan import model
+
+        if len(self.args) < 2:
+            print 'Need name of the user.'
+            return
+        username = self.args[1]
+
+        user = model.User.by_name(unicode(username))
+        if not user:
+            print 'Error: user "%s" not found!' % username
+            return
+        user.delete()
+        model.repo.commit_and_remove()
+        print('Deleted user: %s' % username)
         
 
 class Ratings(CkanCommand):
@@ -820,6 +962,9 @@ class Harvester(CkanCommand):
         self._load_config()
         # Clear the 'No handlers could be found for logger "vdm"' warning message.
         print ""
+        if len(self.args) == 0:
+            self.parser.print_usage()
+            sys.exit(1)
         cmd = self.args[0]
         if cmd == 'source':
             if len(self.args) >= 2:
@@ -878,20 +1023,34 @@ class Harvester(CkanCommand):
 
         from ckan.model import HarvestingJob
         from ckan.controllers.harvesting import HarvestingJobController
+        from ckanext.csw.validation import Validator
+
         jobs = HarvestingJob.filter(status=u"New").all()
         jobs_len = len(jobs)
         jobs_count = 0
         if jobs_len:
             print "Running %s harvesting jobs..." % jobs_len
+            profiles = [
+                x.strip() for x in
+                pylons.config.get(
+                    "ckan.harvestor.validator.profiles", 
+                    "iso19139,gemini2",
+                ).split(",")
+            ]
+            validator = Validator(profiles=profiles)
+            print ""
+            for job in jobs:
+                jobs_count += 1
+                if job.source is None:
+                    print 'ERRROR: no source associated with this job'
+                else:
+                    print "Running job %s/%s: %s" % (jobs_count, jobs_len, job.id)
+                    self.print_harvesting_job(job)
+                    job_controller = HarvestingJobController(job, validator)
+                    job_controller.harvest_documents()
+                    pprint (job.report)
         else:
             print "There are no new harvesting jobs."
-        print ""
-        for job in jobs:
-            jobs_count += 1
-            print "Running job %s/%s: %s" % (jobs_count, jobs_len, job.id)
-            self.print_harvesting_job(job)
-            job_controller = HarvestingJobController(job)
-            job_controller.harvest_documents()
 
     def remove_harvesting_job(self, job_id):
         from ckan import model
@@ -916,7 +1075,9 @@ class Harvester(CkanCommand):
                 source = self.create_harvest_source(url=source_url, user_ref=user_ref, publisher_ref=u'')
         else:
             source = HarvestSource.get(source_id)
-
+        objects = HarvestingJob.filter(status='New', source=source)
+        if objects.count():
+            raise Exception('There is already an unrun job for the harvest source %r'%source.id)
         job = HarvestingJob(
             source=source,
             user_ref=user_ref,
@@ -938,6 +1099,7 @@ class Harvester(CkanCommand):
             sys.exit(1)
         else:
             source = self.create_harvest_source(url=url, user_ref=user_ref, publisher_ref=publisher_ref)
+            self.register_harvesting_job(source.id, user_ref)
             print "Created new harvest source:"
             self.print_harvest_source(source)
             sources = self.get_harvest_sources()
@@ -945,6 +1107,7 @@ class Harvester(CkanCommand):
 
     def remove_harvest_source(self, url):
         from ckan import model
+        model.repo.new_revision()
         sources = model.HarvestSource.filter(url=url)
         if sources.count() == 0:
             print "No such source"
@@ -1016,8 +1179,8 @@ class Harvester(CkanCommand):
         print "source: %s" % job.source.id
         print "   url: %s" % job.source.url
         #print "report: %s" % job.report
-        if job.report and job.report['packages']:
-            for package_id in job.report['packages']:
+        if job.report and job.report['added']:
+            for package_id in job.report['added']:
                 print "   doc: %s" % package_id
         if job.report and job.report['errors']:
             for msg in job.report['errors']:
