@@ -1,6 +1,7 @@
 import logging
 
 import sqlalchemy
+from sqlalchemy.sql import or_
 from sqlalchemy.exceptions import UnboundExecutionError
 
 from common import SearchBackend, SearchQuery, SearchError
@@ -16,16 +17,13 @@ class SqlSearchBackend(SearchBackend):
     
     @property
     def connection(self):
-        try:
-            return meta.Session.connection()
-        except UnboundExecutionError:
-            return meta.engine.connect()
+        return meta.Session.connection(model.Package)
        
     def _setup(self):
         self.register(model.Package, PackageSqlSearchIndex, PackageSqlSearchQuery)
         self.register(model.Group, NoopSearchIndex, GroupSqlSearchQuery)
         self.register(model.Tag, NoopSearchIndex, TagSqlSearchQuery)
-        self.register(model.PackageResource, NoopSearchIndex, ResourceSqlSearchQuery)
+        self.register(model.Resource, NoopSearchIndex, ResourceSqlSearchQuery)
         
         
 class SqlSearchQuery(SearchQuery):
@@ -81,28 +79,35 @@ class ResourceSqlSearchQuery(SqlSearchQuery):
     """ Search for resources in plain SQL. """
 
     def _run(self):
-        q = model.Session.query(model.PackageResource) # TODO authz
+        q = model.Session.query(model.Resource) # TODO authz
         if self.query.terms:
             raise SearchError('Only field specific terms allowed in resource search.')
         #self._check_options_specified_are_allowed('resource search', ['all_fields', 'offset', 'limit'])
         self.options.ref_entity_with_attr = 'id' # has no name
-        resource_fields = model.PackageResource.get_columns()
+        resource_fields = model.Resource.get_columns()
         for field, terms in self.query.fields.items():
             if isinstance(terms, basestring):
                 terms = terms.split()
             if field not in resource_fields:
                 raise SearchError('Field "%s" not recognised in Resource search.' % field)
             for term in terms:
-                model_attr = getattr(model.PackageResource, field)
+                model_attr = getattr(model.Resource, field)
                 if field == 'hash':                
                     q = q.filter(model_attr.ilike(unicode(term) + '%'))
+                elif field in model.Resource.get_extra_columns():
+                    model_attr = getattr(model.Resource, 'extras')
+
+                    like = or_(model_attr.ilike(u'''%%"%s": "%%%s%%",%%''' % (field, term)),
+                               model_attr.ilike(u'''%%"%s": "%%%s%%"}''' % (field, term))
+                              )
+                    q = q.filter(like)
                 else:
                     q = q.filter(model_attr.ilike('%' + unicode(term) + '%'))
         
         order_by = self.options.order_by
         if order_by is not None:
-            if hasattr(model.PackageResource, order_by):
-                q = q.order_by(getattr(model.PackageResource, order_by))
+            if hasattr(model.Resource, order_by):
+                q = q.order_by(getattr(model.Resource, order_by))
         self._db_query(q)
 
 
@@ -146,10 +151,10 @@ class PackageSqlSearchQuery(SqlSearchQuery):
             
         # Filter for options
         if self.options.filter_by_downloadable:
-            q = q.join('package_resources_all', aliased=True)
+            q = q.join('resource_groups_all', 'resources_all', aliased=True)
             q = q.filter(sqlalchemy.and_(
-                model.PackageResource.state==model.State.ACTIVE,
-                model.PackageResource.package_id==model.Package.id))
+                model.Resource.state==model.State.ACTIVE,
+                model.ResourceGroup.package_id==model.Package.id))
         if self.options.filter_by_openness:
             q = q.filter(model.Package.license_id.in_(self.open_licenses))
         
