@@ -1,3 +1,4 @@
+import warnings
 from pylons import config
 from sqlalchemy import MetaData, __version__ as sqav
 from sqlalchemy.schema import Index
@@ -43,7 +44,7 @@ def init_model(engine):
 class Repository(vdm.sqlalchemy.Repository):
     migrate_repository = ckan.migration.__path__[0]
 
-    inited = False
+    tables_created = False
 
     def init_db(self):
         '''Ensures tables, const data and some default config is created.
@@ -56,13 +57,21 @@ class Repository(vdm.sqlalchemy.Repository):
         self.session.remove()
         # sqlite database needs to be recreated each time as the
         # memory database is lost.
-        if not self.inited or self.metadata.bind.name == 'sqlite':
+        if self.metadata.bind.name == 'sqlite':
             # this creates the tables, which isn't required inbetween tests
             # that have simply called rebuild_db.
-            super(Repository, self).init_db()
+            self.create_db()
         else:
-            self.init_const_data()
-            self.init_configuration_data()
+            if not self.tables_created:
+                self.upgrade_db()
+                self.init_configuration_data()
+                self.tables_created = True
+
+    def clean_db(self):
+        metadata = MetaData(self.metadata.bind)
+        metadata.reflect()
+        metadata.drop_all()
+        self.tables_created = False
 
     def init_const_data(self):
         '''Creates 'constant' objects that should always be there in
@@ -93,14 +102,6 @@ class Repository(vdm.sqlalchemy.Repository):
         has shortcuts.
         '''
         self.metadata.create_all(bind=self.metadata.bind)    
-        # creation this way worked fine for normal use but failed on test with
-        # OperationalError: (OperationalError) no such table: xxx
-        # 2009-09-11 interesting all the tests will work if you run them after
-        # doing paster db clean && paster db upgrade !
-        # self.upgrade_db()
-        if self.metadata.bind.name != 'sqlite':
-            self.setup_migration_version_control(self.latest_migration_version())
-            self.create_indexes()
         self.init_const_data()
         self.init_configuration_data()
 
@@ -111,7 +112,7 @@ class Repository(vdm.sqlalchemy.Repository):
 
     def rebuild_db(self):
         '''Clean and init the db'''
-        if asbool(config.get('faster_db_test_hacks')):
+        if self.tables_created:
             # just delete data, leaving tables - this is faster
             self.delete_all()
         else:
@@ -133,6 +134,11 @@ class Repository(vdm.sqlalchemy.Repository):
         for table in tables:
             connection.execute('delete from "%s"' % table.name)
         self.session.commit()
+        ##add default data
+        self.init_const_data()
+        self.init_configuration_data()
+        self.session.commit()
+
 
     def setup_migration_version_control(self, version=None):
         import migrate.versioning.exceptions
@@ -144,35 +150,26 @@ class Repository(vdm.sqlalchemy.Repository):
         except migrate.versioning.exceptions.DatabaseAlreadyControlledError:
             pass
 
-    def create_indexes(self):
-        assert meta.engine.name in ('postgres', 'postgresql'), \
-            'Only postgresql engine supported (not %s).' % meta.engine.name
-        import os
-        from migrate.versioning.script import SqlScript
-        from sqlalchemy.exceptions import ProgrammingError
-        try:
-            path = os.path.join(self.migrate_repository,
-                                'versions',
-                                '021_postgresql_upgrade.sql')
-            script = SqlScript(path)
-            script.run(meta.engine, step=None)
-        except ProgrammingError, e:
-            if not 'already exists' in repr(e):
-                raise
-
     def upgrade_db(self, version=None):
         '''Upgrade db using sqlalchemy migrations.
 
         @param version: version to upgrade to (if None upgrade to latest)
         '''
+        assert meta.engine.name in ('postgres', 'postgresql'), \
+            'Database migration - only Postgresql engine supported (not %s).' %\
+            meta.engine.name
         import migrate.versioning.api as mig
         self.setup_migration_version_control()
         mig.upgrade(self.metadata.bind, self.migrate_repository, version=version)
         self.init_const_data()
-
+        
+        ##this prints the diffs in a readable format
+        ##import pprint
+        ##from migrate.versioning.schemadiff import getDiffOfModelAgainstDatabase
+        ##pprint.pprint(getDiffOfModelAgainstDatabase(self.metadata, self.metadata.bind).colDiffs)
 
 repo = Repository(metadata, Session,
-        versioned_objects=[Package, PackageTag, PackageResource, PackageExtra, PackageGroup, Group]
+        versioned_objects=[Package, PackageTag, Resource, ResourceGroup, PackageExtra, PackageGroup, Group]
         )
 
 
