@@ -45,6 +45,12 @@ class Group(vdm.sqlalchemy.RevisionedObjectMixin,
         self.name = name
         self.title = title
         self.description = description
+    
+    @property
+    def display_name(self): 
+        if self.title is not None and len(self.title): 
+            return "%s (%s)" % (self.title, self.name)
+        return self.name
 
     # not versioned
     def delete(self):
@@ -56,18 +62,18 @@ class Group(vdm.sqlalchemy.RevisionedObjectMixin,
                join('groups').filter_by(id=self.id)
         if load_eager:
             query = query.options(eagerload_all('package_tags.tag'))
-            query = query.options(eagerload_all('package_resources_all'))
+            query = query.options(eagerload_all('resource_groups_all.resources_all'))
         return query
 
     @classmethod
-    def search_by_name(self, text_query):
+    def search_by_name(cls, text_query):
         text_query = text_query.strip().lower()
-        return Session.query(self).filter(self.name.contains(text_query))
+        return Session.query(cls).filter(cls.name.contains(text_query))
 
-    def as_dict(self, ref_package_by='name'):
-        _dict = DomainObject.as_dict(self)
-        _dict['packages'] = [getattr(package, ref_package_by) for package in self.packages]
-        _dict['extras'] = dict([(key, value) for key, value in self.extras.items()])
+    def as_dict(cls, ref_package_by='name'):
+        _dict = DomainObject.as_dict(cls)
+        _dict['packages'] = [getattr(package, ref_package_by) for package in cls.packages]
+        _dict['extras'] = dict([(key, value) for key, value in cls.extras.items()])
         return _dict
 
     def add_package_by_name(self, package_name):
