@@ -47,30 +47,43 @@ class Package(vdm.sqlalchemy.RevisionedObjectMixin,
     
     text_search_fields = ['name', 'title']
 
+    def __init__(self, **kw):
+        from ckan import model
+        super(Package, self).__init__(**kw)
+        resource_group = model.ResourceGroup(label="default")
+        self.resource_groups.append(resource_group)
+
     @classmethod
-    def search_by_name(self, text_query):
+    def search_by_name(cls, text_query):
         text_query = text_query
-        return Session.query(self).filter(self.name.contains(text_query.lower()))
+        return Session.query(cls).filter(cls.name.contains(text_query.lower()))
 
     @classmethod
     def get(cls, reference):
         '''Returns a package object referenced by its id or name.'''
         query = Session.query(cls).filter(cls.id==reference)
         query = query.options(eagerload_all('package_tags.tag'))
-        query = query.options(eagerload_all('package_resources_all'))
+        query = query.options(eagerload_all('resource_groups_all.resources_all'))
         pkg = query.first()
         if pkg == None:
             pkg = cls.by_name(reference)            
         return pkg
     # Todo: Make sure package names can't be changed to look like package IDs?
 
+    @property
+    def resources(self):
+        assert len(self.resource_groups_all) == 1, "can only use resources on packages if there is only one resource_group"
+
+        return self.resource_groups_all[0].resources
+    
+
     def update_resources(self, res_dicts, autoflush=True):
         '''Change this package\'s resources.
         @param res_dicts - ordered list of dicts, each detailing a resource
         The resource dictionaries contain 'url', 'format' etc. Optionally they
-        can also provide the 'id' of the PackageResource, to help matching
-        res_dicts to existing PackageResources. Otherwise, it searches
-        for an exactly matching PackageResource.
+        can also provide the 'id' of the Resource, to help matching
+        res_dicts to existing Resources. Otherwise, it searches
+        for an exactly matchinrce.
         The caller is responsible for creating a revision and committing.'''
         import resource
         assert isinstance(res_dicts, (list, tuple))
@@ -81,11 +94,12 @@ class Package(vdm.sqlalchemy.RevisionedObjectMixin,
             assert isinstance(res_dict, dict)
             id = res_dict.get('id')
             if id:
-                res = Session.query(resource.PackageResource).autoflush(autoflush).get(id)
+                res = Session.query(resource.Resource).autoflush(autoflush).get(id)
                 if res:
                     index_to_res[i] = res
         # Edit resources and create the new ones
         new_res_list = []
+
         for i, res_dict in enumerate(res_dicts):
             if i in index_to_res:
                 res = index_to_res[i]
@@ -96,18 +110,19 @@ class Package(vdm.sqlalchemy.RevisionedObjectMixin,
                 for key in ('id', 'position'):
                     if res_dict.has_key(key):
                         del res_dict[key]
-                res = resource.PackageResource(**res_dict)
+                res = resource.Resource(**res_dict)
             new_res_list.append(res)
-        self.resources = new_res_list
+        self.resource_groups[0].resources = new_res_list
 
-    def add_resource(self, url, format=u'', description=u'', hash=u''):
+    def add_resource(self, url, format=u'', description=u'', hash=u'', **kw):
         import resource
-        self.resources.append(resource.PackageResource(
-            package_id=self.id,
+        self.resources.append(resource.Resource(
+            resource_group_id=self.resource_groups[0].id,
             url=url,
             format=format,
             description=description,
-            hash=hash))
+            hash=hash,
+            **kw))
 
     def add_tag_by_name(self, tagname, autoflush=True):
         from tag import Tag
@@ -274,14 +289,14 @@ class Package(vdm.sqlalchemy.RevisionedObjectMixin,
     ## Licenses are currently integrated into the domain model here.   
  
     @classmethod
-    def get_license_register(self):
-        if not hasattr(self, '_license_register'):
-            self._license_register = LicenseRegister()
-        return self._license_register
+    def get_license_register(cls):
+        if not hasattr(cls, '_license_register'):
+            cls._license_register = LicenseRegister()
+        return cls._license_register
 
     @classmethod
-    def get_license_options(self):
-        register = self.get_license_register()
+    def get_license_options(cls):
+        register = cls.get_license_register()
         return [(l.title, l.id) for l in register.values()]
 
     def get_license(self):
@@ -309,23 +324,33 @@ class Package(vdm.sqlalchemy.RevisionedObjectMixin,
     def all_related_revisions(self):
         '''Returns chronological list of all object revisions related to
         this package. Includes PackageRevisions, PackageTagRevisions,
-        PackageExtraRevisions and PackageResourceRevisions.
+        PackageExtraRevisions and ResourceRevisions.
         @return List of tuples (revision, [list of object revisions of this
                                            revision])
                 Ordered by most recent first.
         '''
+        from tag import PackageTag
+        from resource import ResourceGroup, Resource
+        from package_extra import PackageExtra
+
         results = {} # revision:[PackageRevision1, PackageTagRevision1, etc.]
         for pkg_rev in self.all_revisions:
             if not results.has_key(pkg_rev.revision):
                 results[pkg_rev.revision] = []
             results[pkg_rev.revision].append(pkg_rev)
-        for class_ in get_revisioned_classes_related_to_package():
+        for class_ in [ResourceGroup, Resource, PackageExtra, PackageTag]:
             rev_class = class_.__revision_class__
-            obj_revisions = Session.query(rev_class).filter_by(package_id=self.id).all()
+            if class_ == Resource:
+                q = Session.query(rev_class).join('continuity',
+                                                  'resource_group')
+                obj_revisions = q.filter(ResourceGroup.package_id == self.id).all()
+            else:
+                obj_revisions = Session.query(rev_class).filter_by(package_id=self.id).all()
             for obj_rev in obj_revisions:
                 if not results.has_key(obj_rev.revision):
                     results[obj_rev.revision] = []
                 results[obj_rev.revision].append(obj_rev)
+
         result_list = results.items()
         ourcmp = lambda rev_tuple1, rev_tuple2: \
                  cmp(rev_tuple2[0].timestamp, rev_tuple1[0].timestamp)
@@ -340,25 +365,38 @@ class Package(vdm.sqlalchemy.RevisionedObjectMixin,
     def diff(self, to_revision=None, from_revision=None):
         '''Overrides the diff in vdm, so that related obj revisions are
         diffed as well as PackageRevisions'''
-        import package_extra, resource
+        from tag import PackageTag
+        from resource import ResourceGroup, Resource
+        from package_extra import PackageExtra
+
         results = {} # field_name:diffs
         results.update(super(Package, self).diff(to_revision, from_revision))
-        # Iterate over PackageTag, PackageExtra, PackageResources etc.
-        for obj_class in get_revisioned_classes_related_to_package():
+        # Iterate over PackageTag, PackageExtra, Resources etc.
+        for obj_class in [ResourceGroup, Resource, PackageExtra, PackageTag]:
             obj_rev_class = obj_class.__revision_class__
             # Query for object revisions related to this package            
-            obj_rev_query = Session.query(obj_rev_class).\
-                            filter_by(package_id=self.id).\
-                            join('revision').\
-                            order_by(Revision.timestamp.desc())
+            if obj_class == Resource:
+                obj_rev_query = Session.query(obj_rev_class).\
+                                join('continuity', 'resource_group').\
+                                join('revision').\
+                                filter(ResourceGroup.package_id == self.id).\
+                                order_by(Revision.timestamp.desc())
+            else:
+                obj_rev_query = Session.query(obj_rev_class).\
+                                filter_by(package_id=self.id).\
+                                join('revision').\
+                                order_by(Revision.timestamp.desc())
             # Columns to include in the diff
             cols_to_diff = obj_class.revisioned_fields()
             cols_to_diff.remove('id')
-            cols_to_diff.remove('package_id')
+            if obj_class is Resource:
+                cols_to_diff.remove('resource_group_id')
+            else:
+                cols_to_diff.remove('package_id')
             # Particular object types are better known by an invariant field
-            if obj_class.__name__ == 'PackageTag':
+            if obj_class is PackageTag:
                 cols_to_diff.remove('tag_id')
-            elif obj_class.__name__ == 'PackageExtra':
+            elif obj_class is PackageExtra:
                 cols_to_diff.remove('key')
             # Iterate over each object ID
             # e.g. for PackageTag, iterate over Tag objects
@@ -401,8 +439,11 @@ class Package(vdm.sqlalchemy.RevisionedObjectMixin,
                  model.package_relationship_table.c.revision_id == model.revision_table.c.id, *where),
             and_(model.package_relationship_table.c.object_package_id == model.package_table.c.id,
                  model.package_relationship_table.c.revision_id == model.revision_table.c.id, *where),
-            and_(model.package_resource_table.c.package_id == model.package_table.c.id,
-                 model.package_resource_table.c.revision_id == model.revision_table.c.id, *where),
+            and_(model.resource_group_table.c.package_id == model.package_table.c.id,
+                 model.resource_group_table.c.revision_id == model.revision_table.c.id, *where),
+            and_(model.resource_group_table.c.package_id == model.package_table.c.id,
+                 model.resource_table.c.resource_group_id == model.resource_group_table.c.id,
+                 model.resource_table.c.revision_id == model.revision_table.c.id, *where),
             and_(model.package_tag_table.c.package_id == model.package_table.c.id,
                  model.package_tag_table.c.revision_id == model.revision_table.c.id, *where)
             ]
@@ -454,10 +495,4 @@ class Package(vdm.sqlalchemy.RevisionedObjectMixin,
 
         return fields
 
-def get_revisioned_classes_related_to_package():
-    import resource
-    import package_extra
-    import tag
-    return [tag.PackageTag, resource.PackageResource,
-            package_extra.PackageExtra]
 
