@@ -12,7 +12,7 @@ class HarvestingTestCase(BaseModelApiTestCase):
     reuse_common_fixtures = True
 
     def setup(self):
-        model.repo.init_db()
+        #model.repo.init_db()
         super(HarvestingTestCase, self).setup()
         self.source = None
         self.source1 = None
@@ -26,8 +26,7 @@ class HarvestingTestCase(BaseModelApiTestCase):
         self.job3 = None
 
     def teardown(self):
-        model.repo.init_db() # hack for in-memory sqlite
-        super(HarvestingTestCase, self).teardown()
+        model.repo.delete_all()
 
     def _create_harvest_source_fixture(self, **kwds):
         source = model.HarvestSource(**kwds)
