@@ -52,9 +52,18 @@ class PackagesTestCase(BaseModelApiTestCase):
         for (i, expected_resource) in enumerate(self.package_fixture_data['resources']):
             package_resource = package.resources[i]
             for key in expected_resource.keys():
-                package_resource_value = getattr(package_resource, key)
-                expected_resource_value = expected_resource[key]
-                self.assert_equal(package_resource_value, expected_resource_value)
+                if key == 'extras':
+                    package_resource_extras = getattr(package_resource, key)
+                    expected_resource_extras = expected_resource[key].items()
+                    for expected_extras_key, expected_extras_value in expected_resource_extras:
+                        package_resource_value = package_resource_extras[expected_extras_key],\
+                         'Package:%r Extras:%r Expected_extras:%r' % \
+                         (self.package_fixture_data['name'],
+                          package_resource_extras, expected_resource)
+                else:
+                    package_resource_value = getattr(package_resource, key)
+                    expected_resource_value = expected_resource[key]
+                    self.assert_equal(package_resource_value, expected_resource_value)
 
         # Test Package Entity Get 200.
         offset = self.package_offset(self.package_fixture_data['name'])
@@ -75,7 +84,7 @@ class PackagesTestCase(BaseModelApiTestCase):
         postparams = '%s=1' % self.dumps(self.package_fixture_data)
         res = self.app.post(offset, params=postparams, status=self.STATUS_409_CONFLICT,
                 extra_environ=self.extra_environ)
-        self.remove()
+        self.remove()        
 
     def test_register_post_bad_request(self):
         test_params = {
@@ -92,6 +101,17 @@ class PackagesTestCase(BaseModelApiTestCase):
         postparams = '%s=1' % self.dumps(self.package_fixture_data)
         res = self.app.post(offset, params=postparams, status=self.STATUS_403_ACCESS_DENIED)
 
+    def test_register_post_readonly_fields(self):
+        # (ticket 662) Post a package with readonly field such as 'id'
+        offset = self.offset('/rest/package')
+        data = {'name': u'test_readonly',
+                'id': u'not allowed to be set',
+                }
+        postparams = '%s=1' % self.dumps(data)
+        res = self.app.post(offset, params=postparams,
+                            status=self.STATUS_400_BAD_REQUEST,
+                            extra_environ=self.extra_environ)
+
     def test_entity_get_ok(self):
         package_refs = [self.anna.name, self.anna.id]
         for ref in package_refs:
@@ -113,6 +133,28 @@ class PackagesTestCase(BaseModelApiTestCase):
         res = self.app.get(offset, status=self.STATUS_404_NOT_FOUND)
         self.remove()
 
+    def test_entity_get_then_post(self):
+        # (ticket 662) Ensure an entity you 'get' from a register can be
+        # returned by posting it back
+        offset = self.package_offset(self.war.name)
+        res = self.app.get(offset, status=self.STATUS_200_OK)
+        data = self.loads(res.body)
+        postparams = '%s=1' % self.dumps(data)
+        res = self.app.post(offset, params=postparams,
+                            status=self.STATUS_200_OK,
+                            extra_environ=self.extra_environ)
+
+    def test_entity_post_changed_readonly(self):
+        # (ticket 662) Edit a readonly field gives error
+        offset = self.package_offset(self.war.name)
+        res = self.app.get(offset, status=self.STATUS_200_OK)
+        data = self.loads(res.body)
+        data['id'] = 'illegally changed value'
+        postparams = '%s=1' % self.dumps(data)
+        res = self.app.post(offset, params=postparams,
+                            status=self.STATUS_400_BAD_REQUEST,
+                            extra_environ=self.extra_environ)
+
     def test_entity_update_denied(self):
         offset = self.anna_offset()
         postparams = '%s=1' % self.dumps(self.package_fixture_data)
@@ -151,13 +193,15 @@ class PackagesTestCase(BaseModelApiTestCase):
                 u'format':u'xml',
                 u'description':u'Appendix 1',
                 u'hash':u'def123',
-                u'position':'ignore-this',
-                u'id':'ignore-this',
+                u'alt_url':u'alt123',
+                u'extras':{u'size':u'400'},
             },{
                 u'url':u'http://blah.com/file3.xml',
                 u'format':u'xml',
                 u'description':u'Appenddic 2',
                 u'hash':u'ghi123',
+                u'alt_url':u'alt123',
+                u'extras':{u'size':u'400'},
             }],
             'extras': {
                 u'key3': u'val3', 
@@ -189,11 +233,15 @@ class PackagesTestCase(BaseModelApiTestCase):
         self.assert_equal(resource.format, u'xml')
         self.assert_equal(resource.description, u'Appendix 1')
         self.assert_equal(resource.hash, u'def123')
+        self.assert_equal(resource.alt_url, u'alt123')
+        self.assert_equal(resource.extras['size'], u'400')
         resource = package.resources[1]
         self.assert_equal(resource.url, 'http://blah.com/file3.xml')
         self.assert_equal(resource.format, u'xml')
         self.assert_equal(resource.description, u'Appenddic 2')
         self.assert_equal(resource.hash, u'ghi123')
+        self.assert_equal(resource.alt_url, u'alt123')
+        self.assert_equal(resource.extras['size'], u'400')
 
         # Check unsubmitted fields have not changed.
         # - url
